@@ -21,7 +21,9 @@ class Vertex:
     :type neighbours: Dict[str, Edge]
     """
 
-    def __init__(self, key: str, weight: float = None, neighbours: Dict[str, 'Edge'] = None):
+    def __init__(
+        self, key: str, weight: float = None, neighbours: Dict[str, "Edge"] = None
+    ):
         """
         Vertex class having key, weight and adjacency dictionary of neighbours
 
@@ -83,7 +85,7 @@ class Vertex:
         self._weight = weight
 
     @property
-    def neighbours(self) -> Dict[str, 'Edge']:
+    def neighbours(self) -> Dict[str, "Edge"]:
         """
         Neighbouring vertices
 
@@ -92,7 +94,7 @@ class Vertex:
         return self._neighbours
 
     @neighbours.setter
-    def neighbours(self, neighbours: Dict[str, 'Edge']) -> None:
+    def neighbours(self, neighbours: Dict[str, "Edge"]) -> None:
         """
         Neighbouring vertices
 
@@ -114,7 +116,7 @@ class Vertex:
         """
         return neighbour in self._neighbours
 
-    def add_neighbour(self, neighbour: str, weight: float = None) -> 'Vertex':
+    def add_neighbour(self, neighbour: str, weight: float = None) -> "Vertex":
         """
         Adds a neighbour, default edge weight as :py:attr:`Edge.DEFAULT_EDGE_WEIGHT`
 
@@ -126,11 +128,13 @@ class Vertex:
         :return: Self
         """
         if self.is_neighbour_exists(neighbour):
-            raise Exception(f'Neighbour {neighbour} already exists for {self.__key}, delete it first')
+            raise Exception(
+                f"Neighbour {neighbour} already exists for {self.__key}, delete it first"
+            )
         self.neighbours[neighbour] = Edge(self.key, neighbour, weight)
         return self
 
-    def get_neighbour(self, neighbour: str) -> 'Edge':
+    def get_neighbour(self, neighbour: str) -> "Edge":
         """
         Gets a neighbour
 
@@ -140,10 +144,12 @@ class Vertex:
         :return: Edge representing the neighbour
         """
         if not self.is_neighbour_exists(neighbour):
-            raise Exception(f'Neighbour {neighbour} does not exists for {self.__key}, create it first')
+            raise Exception(
+                f"Neighbour {neighbour} does not exists for {self.__key}, create it first"
+            )
         return self.neighbours.get(neighbour)
 
-    def update_neighbour(self, neighbour: str, weight: float = None) -> 'Vertex':
+    def update_neighbour(self, neighbour: str, weight: float = None) -> "Vertex":
         """
         Updates a neighbour, default edge weight as :py:attr:`Edge.DEFAULT_EDGE_WEIGHT`
 
@@ -157,7 +163,7 @@ class Vertex:
         self.neighbours[neighbour] = Edge(self.key, neighbour, weight)
         return self
 
-    def update_weight(self, weight: float) -> 'Vertex':
+    def update_weight(self, weight: float) -> "Vertex":
         """
         Updates vertex weight
 
@@ -179,7 +185,9 @@ class Vertex:
         :return: Deleted Edge
         """
         if not self.is_neighbour_exists(neighbour):
-            raise Exception(f'Neighbour {neighbour} does not exists for {self.__key}, create it first')
+            raise Exception(
+                f"Neighbour {neighbour} does not exists for {self.__key}, create it first"
+            )
         return self.neighbours.pop(neighbour)
 
     def degree(self) -> int:
